# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.spqr.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/mdb/spqr/v1/user_service.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a#yandex/cloud/mdb/spqr/v1/user.proto\"d\n\x0eGetUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\"r\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x96\x01\n\x1aListUsersAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x18\n\x08revision\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"[\n\x11ListUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.mdb.spqr.v1.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"l\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\tuser_spec\x18\x02 \x01(\x0b\x32\".yandex.cloud.mdb.spqr.v1.UserSpec\";\n\x12\x43reateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xd6\x02\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\x12\x39\n\x0bpermissions\x18\x05 \x03(\x0b\x32$.yandex.cloud.mdb.spqr.v1.Permission\x12\x38\n\x08settings\x18\x06 \x01(\x0b\x32&.yandex.cloud.mdb.spqr.v1.UserSettings\x12*\n\x06grants\x18\x07 \x03(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\";\n\x12UpdateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"g\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\";\n\x12\x44\x65leteUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t2\xa1\x08\n\x0bUserService\x12\x91\x01\n\x03Get\x12(.yandex.cloud.mdb.spqr.v1.GetUserRequest\x1a\x1e.yandex.cloud.mdb.spqr.v1.User\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}\x12\x95\x01\n\x04List\x12*.yandex.cloud.mdb.spqr.v1.ListUsersRequest\x1a+.yandex.cloud.mdb.spqr.v1.ListUsersResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-spqr/v1/clusters/{cluster_id}/users\x12\xa9\x01\n\x0eListAtRevision\x12\x34.yandex.cloud.mdb.spqr.v1.ListUsersAtRevisionRequest\x1a+.yandex.cloud.mdb.spqr.v1.ListUsersResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-spqr/v1/clusters/{cluster_id}/users\x12\xaf\x01\n\x06\x43reate\x12+.yandex.cloud.mdb.spqr.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x31\",/managed-spqr/v1/clusters/{cluster_id}/users:\x01*\x12\xbb\x01\n\x06Update\x12+.yandex.cloud.mdb.spqr.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02=28/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12+.yandex.cloud.mdb.spqr.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:*8/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}Ba\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_GETUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['password']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['grants']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['grants']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_USERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002:\0228/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002.\022,/managed-spqr/v1/clusters/{cluster_id}/users'
  _globals['_USERSERVICE'].methods_by_name['ListAtRevision']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ListAtRevision']._serialized_options = b'\202\323\344\223\002.\022,/managed-spqr/v1/clusters/{cluster_id}/users'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\0021\",/managed-spqr/v1/clusters/{cluster_id}/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002=28/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002:*8/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_GETUSERREQUEST']._serialized_start=279
  _globals['_GETUSERREQUEST']._serialized_end=379
  _globals['_LISTUSERSREQUEST']._serialized_start=381
  _globals['_LISTUSERSREQUEST']._serialized_end=495
  _globals['_LISTUSERSATREVISIONREQUEST']._serialized_start=498
  _globals['_LISTUSERSATREVISIONREQUEST']._serialized_end=648
  _globals['_LISTUSERSRESPONSE']._serialized_start=650
  _globals['_LISTUSERSRESPONSE']._serialized_end=741
  _globals['_CREATEUSERREQUEST']._serialized_start=743
  _globals['_CREATEUSERREQUEST']._serialized_end=851
  _globals['_CREATEUSERMETADATA']._serialized_start=853
  _globals['_CREATEUSERMETADATA']._serialized_end=912
  _globals['_UPDATEUSERREQUEST']._serialized_start=915
  _globals['_UPDATEUSERREQUEST']._serialized_end=1257
  _globals['_UPDATEUSERMETADATA']._serialized_start=1259
  _globals['_UPDATEUSERMETADATA']._serialized_end=1318
  _globals['_DELETEUSERREQUEST']._serialized_start=1320
  _globals['_DELETEUSERREQUEST']._serialized_end=1423
  _globals['_DELETEUSERMETADATA']._serialized_start=1425
  _globals['_DELETEUSERMETADATA']._serialized_end=1484
  _globals['_USERSERVICE']._serialized_start=1487
  _globals['_USERSERVICE']._serialized_end=2544
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/host_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/host_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import maintenance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/compute/v1/host_group.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)yandex/cloud/compute/v1/maintenance.proto\"\xa4\x04\n\tHostGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.compute.v1.HostGroup.LabelsEntry\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12\x39\n\x06status\x18\x08 \x01(\x0e\x32).yandex.cloud.compute.v1.HostGroup.Status\x12\x0f\n\x07type_id\x18\t \x01(\t\x12\x46\n\x12maintenance_policy\x18\n \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12:\n\x0cscale_policy\x18\x0b \x01(\x0b\x32$.yandex.cloud.compute.v1.ScalePolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"\xca\x01\n\x04Host\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.yandex.cloud.compute.v1.Host.Status\x12\x11\n\tserver_id\x18\x03 \x01(\t\x12\x39\n\x0breplacement\x18\x04 \x01(\x0b\x32$.yandex.cloud.compute.v1.Replacement\"2\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\"\x7f\n\x0bScalePolicy\x12\x46\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32/.yandex.cloud.compute.v1.ScalePolicy.FixedScaleH\x00\x1a\x1a\n\nFixedScale\x12\x0c\n\x04size\x18\x01 \x01(\x03\x42\x0c\n\nscale_type\"O\n\x0bReplacement\x12\x0f\n\x07host_id\x18\x01 \x01(\t\x12/\n\x0b\x64\x65\x61\x64line_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.host_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_HOSTGROUP_LABELSENTRY']._loaded_options = None
  _globals['_HOSTGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_HOSTGROUP']._serialized_start=146
  _globals['_HOSTGROUP']._serialized_end=694
  _globals['_HOSTGROUP_LABELSENTRY']._serialized_start=562
  _globals['_HOSTGROUP_LABELSENTRY']._serialized_end=607
  _globals['_HOSTGROUP_STATUS']._serialized_start=609
  _globals['_HOSTGROUP_STATUS']._serialized_end=694
  _globals['_HOST']._serialized_start=697
  _globals['_HOST']._serialized_end=899
  _globals['_HOST_STATUS']._serialized_start=849
  _globals['_HOST_STATUS']._serialized_end=899
  _globals['_SCALEPOLICY']._serialized_start=901
  _globals['_SCALEPOLICY']._serialized_end=1028
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=988
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=1014
  _globals['_REPLACEMENT']._serialized_start=1030
  _globals['_REPLACEMENT']._serialized_end=1109
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2
import yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SearchIndexServiceStub:
    """SearchIndexService provides operations for managing search indexes."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.CreateSearchIndexRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create a new search index in [asynchronous mode](/docs/foundation-models/concepts/#working-mode)."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.GetSearchIndexRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex,
    ]
    """Retrieve details of a specific search index by its ID."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.UpdateSearchIndexRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex,
    ]
    """Update an existing search index."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexResponse,
    ]
    """Delete a search index by its ID."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesResponse,
    ]
    """List search indexes in a specific folder."""

class SearchIndexServiceAsyncStub:
    """SearchIndexService provides operations for managing search indexes."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.CreateSearchIndexRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create a new search index in [asynchronous mode](/docs/foundation-models/concepts/#working-mode)."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.GetSearchIndexRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex,
    ]
    """Retrieve details of a specific search index by its ID."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.UpdateSearchIndexRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex,
    ]
    """Update an existing search index."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexResponse,
    ]
    """Delete a search index by its ID."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesResponse,
    ]
    """List search indexes in a specific folder."""

class SearchIndexServiceServicer(metaclass=abc.ABCMeta):
    """SearchIndexService provides operations for managing search indexes."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.CreateSearchIndexRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create a new search index in [asynchronous mode](/docs/foundation-models/concepts/#working-mode)."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.GetSearchIndexRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex]]:
        """Retrieve details of a specific search index by its ID."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.UpdateSearchIndexRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex]]:
        """Update an existing search index."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.DeleteSearchIndexResponse]]:
        """Delete a search index by its ID."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.searchindex.search_index_service_pb2.ListSearchIndicesResponse]]:
        """List search indexes in a specific folder."""

def add_SearchIndexServiceServicer_to_server(servicer: SearchIndexServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/zone_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/zone_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.baremetal.v1alpha import zone_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_zone__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/baremetal/v1alpha/zone_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a)yandex/cloud/baremetal/v1alpha/zone.proto\x1a\x1dyandex/cloud/validation.proto\"+\n\x0eGetZoneRequest\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=20\"J\n\x10ListZonesRequest\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x01\x10\x64\"g\n\x11ListZonesResponse\x12\x33\n\x05zones\x18\x01 \x03(\x0b\x32$.yandex.cloud.baremetal.v1alpha.Zone\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xdb\x01\n\x0bZoneService\x12]\n\x03Get\x12..yandex.cloud.baremetal.v1alpha.GetZoneRequest\x1a$.yandex.cloud.baremetal.v1alpha.Zone\"\x00\x12m\n\x04List\x12\x30.yandex.cloud.baremetal.v1alpha.ListZonesRequest\x1a\x31.yandex.cloud.baremetal.v1alpha.ListZonesResponse\"\x00\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.zone_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETZONEREQUEST'].fields_by_name['zone_id']._loaded_options = None
  _globals['_GETZONEREQUEST'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_LISTZONESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTZONESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_GETZONEREQUEST']._serialized_start=159
  _globals['_GETZONEREQUEST']._serialized_end=202
  _globals['_LISTZONESREQUEST']._serialized_start=204
  _globals['_LISTZONESREQUEST']._serialized_end=278
  _globals['_LISTZONESRESPONSE']._serialized_start=280
  _globals['_LISTZONESRESPONSE']._serialized_end=383
  _globals['_ZONESERVICE']._serialized_start=386
  _globals['_ZONESERVICE']._serialized_end=605
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.mdb.mysql.v1.user_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster the user belongs to.

    To get this ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to return information about.

    To get this name, make a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GetUserRequest = GetUserRequest

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list the users in.

    To get this ID, make a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the API returns a [ListUsersResponse.next_page_token] that can be used to get the next page of results in the subsequent [UserService.List] requests.
    """
    page_token: builtins.str
    """Page token that can be used to iterate through multiple pages of results.

    To get the next page of results, set [page_token] to the [ListUsersResponse.next_page_token] returned by the previous [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """The token that can be used to get the next page of results.

    If the number of results is larger than [ListUsersRequest.page_size], use the [next_page_token] as the value for the [ListUsersRequest.page_token] in the subsequent [UserService.List] request to iterate through multiple pages of results.

    Each of the subsequent [UserService.List] requests should use the [next_page_token] value returned by the previous request to continue paging through the results.
    """
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.mysql.v1.user_pb2.User]:
        """List of users."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.mdb.mysql.v1.user_pb2.User] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to create the user in.

    To get this ID, make a [ClusterService.List] request.
    """
    @property
    def user_spec(self) -> yandex.cloud.mdb.mysql.v1.user_pb2.UserSpec:
        """Configuration of the user."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_spec: yandex.cloud.mdb.mysql.v1.user_pb2.UserSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user_spec", b"user_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_spec", b"user_spec"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class CreateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster the user is being created in."""
    user_name: builtins.str
    """Name of the user that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___CreateUserMetadata = CreateUserMetadata

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    GLOBAL_PERMISSIONS_FIELD_NUMBER: builtins.int
    CONNECTION_LIMITS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_PLUGIN_FIELD_NUMBER: builtins.int
    GENERATE_PASSWORD_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to update the user in.

    To get this ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to update.

    To get this name, make a [UserService.List] request.
    """
    password: builtins.str
    """New password for the user."""
    authentication_plugin: yandex.cloud.mdb.mysql.v1.user_pb2.AuthPlugin.ValueType
    """New user authentication plugin."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which settings of the user should be updated."""

    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.mysql.v1.user_pb2.Permission]:
        """A new set of permissions that should be granted to the user."""

    @property
    def global_permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.mdb.mysql.v1.user_pb2.GlobalPermission.ValueType]:
        """New set of global permissions to grant to the user."""

    @property
    def connection_limits(self) -> yandex.cloud.mdb.mysql.v1.user_pb2.ConnectionLimits:
        """Set of changed user connection limits."""

    @property
    def generate_password(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Generate password using Connection Manager."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[yandex.cloud.mdb.mysql.v1.user_pb2.Permission] | None = ...,
        global_permissions: collections.abc.Iterable[yandex.cloud.mdb.mysql.v1.user_pb2.GlobalPermission.ValueType] | None = ...,
        connection_limits: yandex.cloud.mdb.mysql.v1.user_pb2.ConnectionLimits | None = ...,
        authentication_plugin: yandex.cloud.mdb.mysql.v1.user_pb2.AuthPlugin.ValueType = ...,
        generate_password: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_limits", b"connection_limits", "generate_password", b"generate_password", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authentication_plugin", b"authentication_plugin", "cluster_id", b"cluster_id", "connection_limits", b"connection_limits", "generate_password", b"generate_password", "global_permissions", b"global_permissions", "password", b"password", "permissions", b"permissions", "update_mask", b"update_mask", "user_name", b"user_name"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class UpdateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster the user is being updated in."""
    user_name: builtins.str
    """Name of the user that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___UpdateUserMetadata = UpdateUserMetadata

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to delete the user from.

    To get this ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to delete.

    To get this name, make a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

@typing.final
class DeleteUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster the user is being deleted from."""
    user_name: builtins.str
    """Name of the user that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserMetadata = DeleteUserMetadata

@typing.final
class GrantUserPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to grant permission to the user in.

    To get this ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to grant permission to.

    To get this name, make a [UserService.List] request.
    """
    @property
    def permission(self) -> yandex.cloud.mdb.mysql.v1.user_pb2.Permission:
        """Permission that should be granted to the specified user."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        permission: yandex.cloud.mdb.mysql.v1.user_pb2.Permission | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["permission", b"permission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "permission", b"permission", "user_name", b"user_name"]) -> None: ...

global___GrantUserPermissionRequest = GrantUserPermissionRequest

@typing.final
class GrantUserPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster the user is being granted a permission in."""
    user_name: builtins.str
    """Name of the user that is being granted a permission."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GrantUserPermissionMetadata = GrantUserPermissionMetadata

@typing.final
class RevokeUserPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to revoke permission from the user in.

    To get this ID, make a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to revoke permission from.

    To get this name, make a [UserService.List] request.
    """
    @property
    def permission(self) -> yandex.cloud.mdb.mysql.v1.user_pb2.Permission:
        """Permission that should be revoked from the user."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        permission: yandex.cloud.mdb.mysql.v1.user_pb2.Permission | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["permission", b"permission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "permission", b"permission", "user_name", b"user_name"]) -> None: ...

global___RevokeUserPermissionRequest = RevokeUserPermissionRequest

@typing.final
class RevokeUserPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster the user is being revoked a permission in."""
    user_name: builtins.str
    """Name of the user whose permission is being revoked."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___RevokeUserPermissionMetadata = RevokeUserPermissionMetadata



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.tts.v3 import tts_pb2 as yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/tts/v3/tts_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SynthesizerStub(object):
    """A set of methods for voice synthesis.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UtteranceSynthesis = channel.unary_stream(
                '/speechkit.tts.v3.Synthesizer/UtteranceSynthesis',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.UtteranceSynthesisRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.UtteranceSynthesisResponse.FromString,
                _registered_method=True)
        self.StreamSynthesis = channel.stream_stream(
                '/speechkit.tts.v3.Synthesizer/StreamSynthesis',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.StreamSynthesisRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.StreamSynthesisResponse.FromString,
                _registered_method=True)


class SynthesizerServicer(object):
    """A set of methods for voice synthesis.
    """

    def UtteranceSynthesis(self, request, context):
        """Synthesizing text into speech.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSynthesis(self, request_iterator, context):
        """Bidirectional streaming RPC for real-time synthesis.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SynthesizerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UtteranceSynthesis': grpc.unary_stream_rpc_method_handler(
                    servicer.UtteranceSynthesis,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.UtteranceSynthesisRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.UtteranceSynthesisResponse.SerializeToString,
            ),
            'StreamSynthesis': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamSynthesis,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.StreamSynthesisRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.StreamSynthesisResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'speechkit.tts.v3.Synthesizer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('speechkit.tts.v3.Synthesizer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Synthesizer(object):
    """A set of methods for voice synthesis.
    """

    @staticmethod
    def UtteranceSynthesis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/speechkit.tts.v3.Synthesizer/UtteranceSynthesis',
            yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.UtteranceSynthesisRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.UtteranceSynthesisResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamSynthesis(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/speechkit.tts.v3.Synthesizer/StreamSynthesis',
            yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.StreamSynthesisRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.StreamSynthesisResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
